@@ -266,8 +266,6 @@ class NNTrainer:
         pass
 
     def _reduce_iteration(self, its):
-        if len(its) == 1:
-            return its[0]
         reduced = {}.fromkeys(its[0].keys(), None)
         for key in reduced:
             if isinstance(its[0][key], _base_metrics.COINNAverages):
@@ -353,4 +351,4 @@ class NNTrainer:
         return kw.get('epoch') - self.cache['best_local_epoch'] >= self.cache['args'].get('patience', 'epochs')
 
     def _set_log_headers(self):
-        self.cache['log_header'] = 'Loss,Precision,Recall,F1,Accuracy'
+        self.cache['log_header'] = 'Loss,Accuracy,F1,Precision,Recall'
