@@ -65,10 +65,6 @@ class COINNTrainer(_NNTrainer):
         self.nn[first_model].train()
         self.optimizer[first_optim].zero_grad()
 
-        if self.input.get('avg_grads_file'):
-            self.step()
-            self.save_checkpoint(file_path=self.cache['log_dir'] + _sep + self.cache['current_nn_state'])
-
         its = []
         for _ in range(self.cache['local_iterations']):
             it = self.iteration(self.next_batch(dataset_cls))
@@ -91,6 +87,7 @@ class COINNTrainer(_NNTrainer):
         out[Key.VALIDATION_SERIALIZABLE] = [vars(avg), vars(scores)]
         out.update(**self.next_epoch())
         out.update(**self._on_epoch_end(self.cache['epoch'], None, None, avg, scores))
+        out['epoch'] = self.cache['epoch']
         return out
 
     def test_distributed(self, dataset_cls):
@@ -99,6 +96,7 @@ class COINNTrainer(_NNTrainer):
         avg, scores = self.evaluation(mode='dist_test', save_pred=True,
                                       dataset_list=[self._get_test_dataset(dataset_cls)])
         out[Key.TEST_SERIALIZABLE] = [vars(avg), vars(scores)]
+        out['epoch'] = self.cache['epoch']
         return out
 
     def cache_data_indices(self, dataset_cls, split_key='train'):
